@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)admin.c	1.7 07/01/23 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)admin.c 1.7 07/01/23 J. Schilling"
+#endif
 /*
  * @(#)admin.c 1.39 06/12/12
  */
@@ -132,11 +141,7 @@ static	char *	getval __PR((register char *sourcep, register char *destp));
 static	int	val_list __PR((register char *list));
 static	int	pos_ser __PR((char *s1, char *s2));
 static	int	range __PR((register char *line));
-static	void	code __PR((FILE *iptr, char *afile, int offset, int thash, struct packet *gpkt));
-
-/*static	void admin(), cmt_ba(), putmrs(), code();*/
-/*static	char *adjust(), *getval();*/
-/*static	int val_list(), pos_ser(), range(), fgetchk();*/
+static	void	code __PR((FILE *iptr, char *afile, int offset, int thash, struct packet *pktp));
 
 extern int	org_ihash;
 extern int	org_chash;
@@ -265,7 +270,13 @@ char *argv[];
 				}
 				break;
 			case 'm':	/* mr flag */
-				if (!(*p) || *p == '-')
+				/*
+				 * Former sccs versions did allow to call
+				 * admin -fv -m -i... to specify "no mr".
+				 * With getopt, this only works with '-m '
+				 * or -m ''.
+				 */
+				if (*p == '-')
 					fatal(gettext("bad m argument (ad34)"));
 				Mrs = p;
 				repl(Mrs,'\n',' ');
@@ -544,27 +555,35 @@ char	*afile;
 	struct deltab dt;	/* see file defines.h */
 	struct stats stats;	/* see file defines.h */
 	struct stat sbuf;
-	FILE	*iptr = NULL;
+	FILE	*iptr;
 	register int k;
 	register char *cp;
 	register signed char *q;
 	char	*in_f;		/* ptr holder for lockflag vals in SCCS file */
 	char	nline[BUFSIZ];
 	char	*p_lval, *tval;
-	char	*lval = 0;
+	char	*lval;
 	char	f;		/* character holder for flag character */
 	char	line[BUFSIZ];
 	int	i;		/* used in forking procedure */
-	int	ck_it  =  0;	/* used for lockflag checking */
+	int	ck_it;		/* used for lockflag checking */
 	int     offset;
 	int     thash;
 	int	status;		/* used for status return from fork */
-	int	from_stdin = 0; /* used for ifile */
+	int	from_stdin;	/* used for ifile */
 	extern	char had_dir;
 
 	if (setjmp(Fjmp))	/* set up to return here from 'fatal' */
 		return;		/* and return to caller of admin */
 
+	/*
+	 * Initialize here to avoid setjmp() clobbering warnings
+	 */
+	iptr = NULL;
+	lval = NULL;
+	ck_it = 0;
+	from_stdin = 0;
+
 	zero((char *) &stats,sizeof(stats));
 
 	if (HADI && had_dir) /* directory not allowed with `i' keyletter */
@@ -893,7 +912,7 @@ char	*afile;
 					*--q = '\0';	/* character */
 				}
 			}
-			if (rm_flag[k])
+			if (rm_flag[k]) {
 				if (f == LOCKFLAG) {
 					if (unlock) {
 						in_f = lval;
@@ -904,6 +923,7 @@ char	*afile;
 					else had_flag[k] = 0;
 				}
 				else had_flag[k] = 0;
+			}
 		}
 
 
@@ -1218,7 +1238,7 @@ int	fflag;
 FILE	*inptr;
 struct	packet *pkt;
 {
-	int	nline, index, search_on;
+	int	nline, idx = 0, search_on = 0;
 	char	lastchar;
 	char	line[BUFSIZ];	
 
@@ -1237,9 +1257,9 @@ struct	packet *pkt;
 	      goto err;
 	   }
 	   search_on = 0;
-	   for (index=BUFSIZ-1; index >= 0; index--) {
+	   for (idx = BUFSIZ-1; idx >= 0; idx--) {
 	      if (search_on == 1) {
-		 if (line[index] == '\0') {
+		 if (line[idx] == '\0') {
 	err:
 		    if (fflag) {
 		       return(-1);
@@ -1251,9 +1271,9 @@ struct	packet *pkt;
 		    }
 		 }
 	      } else {
-		 if (line[index] == '\0') {
+		 if (line[idx] == '\0') {
 		    search_on = 1;
-		    lastchar = line[index-1];
+		    lastchar = line[idx-1];
 	   	    if (lastchar == '\n') {
 		       nline++;
 		    }
@@ -1463,12 +1483,12 @@ register char *line;
 }
 
 static void
-code(iptr,afile,offset,thash,gpkt)
+code(iptr,afile,offset,thash,pktp)
 FILE *iptr;
 char *afile;
 int offset;
 int thash;
-struct packet *gpkt;
+struct packet *pktp;
 {
 	FILE *eptr;
 
@@ -1486,7 +1506,7 @@ struct packet *gpkt;
 	/* close the stream to xfile and reopen it at offset.  Offset is
 	 * the end of sccs header info and before gfile contents
 	 */
-	putline(gpkt,0);
+	putline(pktp,0);
 	fseek(Xiop,offset,0);
-	gpkt->p_nhash = thash;
+	pktp->p_nhash = thash;
 }
