@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)delta.c	1.5 07/01/20 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)delta.c 1.5 07/01/20 J. Schilling"
+#endif
 /*
  * @(#)delta.c 1.40 06/12/12
  */
@@ -35,7 +44,7 @@
 # include	<had.h>
 # include	<i18n.h>
 # include	<sys/utsname.h>
-# include	<sys/wait.h>
+# include	<schily/wait.h>
 # include	<ccstypes.h>
 
 struct stat Statbuf;
@@ -51,7 +60,16 @@ static int	num_files;
 static int	number_of_lines;
 static off_t	size_of_file;
 static off_t	Szqfile;
-static char	BDiffpgm[]  =   NOGETTEXT("/usr/bin/bdiff");
+#ifdef	PROTOTYPES
+static char	BDiffpgm[]  =   NOGETTEXT(INS_BASE "/ccs/bin/bdiff");
+#else
+/*
+ * XXX If you are using a K&R compiler and like to install to a path
+ * XXX different from "/usr/ccs/bin/", you need to edit this string.
+ */
+static char	BDiffpgm[]  =   NOGETTEXT("/usr/ccs/bin/bdiff");
+#endif
+static char	BDiffpgm2[]  =   NOGETTEXT("bdiff");
 static char	Diffpgm[]   =   NOGETTEXT("/usr/bin/diff");
 static char	Diffpgm2[]   =   NOGETTEXT("/bin/diff");
 static char	*ilist, *elist, *glist, Cmrs[300], *Nsid;
@@ -69,21 +87,31 @@ int	Did_id;
 extern FILE	*Xiop;
 extern int	Xcreate;
 
-void	clean_up();
-void	enter();
+	void    clean_up __PR((void));
+	void	enter	__PR((struct packet *pkt, int ch, int n, struct sid *sidp));
 
-static void	skipline(), insert(), delete(), before(), after();
-static void	fgetchk(), putmrs(), putcmrs(), mkixg();
-static char	*rddiff(), *linerange();
-static int	mkdelt(), getdiff();
-static FILE*	dodiff();
-static struct pfile*	rdpfile();
-static	void	delta();
+	int	main __PR((int argc, char **argv));
+static void	delta __PR((char *file));
+static int	mkdelt __PR((struct packet *pkt, struct sid *sp, struct sid *osp, int diffloop, int orig_nlines));
+static void	mkixg __PR((struct packet *pkt, int reason, int ch));
+static void	putmrs __PR((struct packet *pkt));
+static void	putcmrs __PR((struct packet *pkt));
+static struct pfile *rdpfile __PR((struct packet *pkt, struct sid *sp));
+static FILE *	dodiff __PR((char *newf, char *oldf, int difflim));
+static int	getdiff __PR((char *type, int *plinenum));
+static void	insert __PR((struct packet *pkt, int linenum, int n, int ser));
+static void	delete __PR((struct packet *pkt, int linenum, int n, int ser));
+static void	after __PR((struct packet *pkt, int n));
+static void	before __PR((struct packet *pkt, int n));
+static char *	linerange __PR((char *cp, int *low, int *high));
+static void	skipline __PR((char *lp, int num));
+static char *	rddiff __PR((char *s, int n));
+static void	fgetchk __PR((char *file, struct packet *pkt));
 
 extern int	org_ihash;
 extern int	org_chash;
 extern int	org_uchash;
-extern char *		saveid;
+extern char	saveid[];
 
 int
 main(argc,argv)
@@ -104,12 +132,15 @@ register char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
-#ifdef	USE_NLS
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
-#endif
 
 	Fflags = FTLEXIT | FTLMSG | FTLCLN;
 
@@ -215,8 +246,10 @@ register char *argv[];
 			if (had[c - 'a']++)
 				fatal(gettext("key letter twice (cm2)"));
 	}
+#ifdef	NO_BDIFF
 #if	!(defined(SVR4) && defined(sun))
 	had['d' - 'a'] = 1;			/* Do not use "bdiff" */
+#endif
 #endif
 
 	for(i=1; i<argc; i++){
@@ -283,7 +316,7 @@ char *file;
 	gpkt.p_reopen = 1;
 	gpkt.p_stdout = stdout;
 	copy(auxf(gpkt.p_file,'g'),gfilename);
-	Gin = xfopen(gfilename, O_RDONLY);
+	Gin = xfopen(gfilename, O_RDONLY|O_BINARY);
 	pp = rdpfile(&gpkt,&sid);
 
 	if((pp->pf_cmrlist)==0)
@@ -351,10 +384,9 @@ char *file;
 		efp = xfcreat(auxf(gpkt.p_file,'e'),0644);
 		encode(Gin,efp);
 		fclose(efp);
-		efp = NULL;
 		if (Gin)
 			fclose(Gin);
-		Gin = xfopen(auxf(gpkt.p_file,'e'), O_RDONLY);
+		Gin = xfopen(auxf(gpkt.p_file,'e'), O_RDONLY|O_BINARY);
 	}
 	copy(auxf(gpkt.p_file,'d'),dfilename);
 	gpkt.p_gout = xfcreat(dfilename,(mode_t)0444);
@@ -447,7 +479,7 @@ char *file;
 		else
 			Diffin = dodiff(gfilename, dfilename, difflim);
 
-		while (n = getdiff(&type,&linenum)) {
+		while ((n = getdiff(&type,&linenum)) != 0) {
 			if (type == INS) {
 				inserted += n;
 				insert(&gpkt,linenum,n,newser);
@@ -495,7 +527,7 @@ char *file;
 				/*
 				Re-open s-file.
 				*/
-				gpkt.p_iop = xfopen(gpkt.p_file, O_RDONLY);
+				gpkt.p_iop = xfopen(gpkt.p_file, O_RDONLY|O_BINARY);
 				setbuf(gpkt.p_iop,gpkt.p_buf);
 				/*
 				Reset counters.
@@ -773,13 +805,13 @@ struct sid *sp;
 	if ((user=logname()) == NULL)
 	   fatal(gettext("User ID not in password file (cm9)"));
 	zero((char *)&goodpf,sizeof(goodpf));
-	in = xfopen(auxf(pkt->p_file,'p'), O_RDONLY);
+	in = xfopen(auxf(pkt->p_file,'p'), O_RDONLY|O_BINARY);
 	outname = auxf(pkt->p_file, 'q');
-	if ((fd=open(outname, O_WRONLY|O_CREAT|O_EXCL, 0444)) < 0) {
+	if ((fd=open(outname, O_WRONLY|O_CREAT|O_EXCL|O_BINARY, 0444)) < 0) {
 	   fatal(gettext("cannot create lock file (cm4)"));
 	}
 	fchmod(fd, (mode_t)0644);
-	out = fdfopen(fd, 1);
+	out = fdfopen(fd, O_WRONLY|O_BINARY);
 	while (fgets(line,sizeof(line),in) != NULL) {
 		pf_ab(line,&pf,1);
 		pf.pf_date = cutoff;
@@ -792,9 +824,7 @@ struct sid *sp;
 						xmsg(outname, NOGETTEXT("rdpfile"));
 					if (fclose(out) == EOF)
 						xmsg(outname, NOGETTEXT("rdpfile"));
-					out = NULL;
 					fclose(in);
-					in = NULL;
 					fatal(gettext("missing -r argument (de1)"));
 				}
 				goodpf = pf;
@@ -815,9 +845,7 @@ struct sid *sp;
 							xmsg(outname, NOGETTEXT("rdpfile"));
 						if (fclose(out) == EOF)
 							xmsg(outname, NOGETTEXT("rdpfile"));
-						out = NULL;
 						fclose(in);
-						in = NULL;
 						fatal(ambig);
 					}
 					goodpf = pf;
@@ -834,10 +862,8 @@ struct sid *sp;
 		xmsg(outname, NOGETTEXT("rdpfile"));
 	if (fclose(out) == EOF)
 		xmsg(outname, NOGETTEXT("rdpfile"));
-	out = NULL;
 	copy(auxf(pkt->p_file,'p'),Pfilename);
 	fclose(in);
-	in = NULL;
 	if (!goodpf.pf_user[0])
 		fatal(gettext("login name or SID specified not in p-file (de2)"));
 	return(&goodpf);
@@ -873,16 +899,18 @@ int difflim;
  		   execl(Diffpgm2,Diffpgm2,oldf,newf,0);
  		} else {
  		   execl(BDiffpgm,BDiffpgm,oldf,newf,num,"-s",0);
+ 		   execl(BDiffpgm2,BDiffpgm,oldf,newf,num,"-s",0);
  		}
 		close(1);
 		_exit(32);	/* tell parent that 'execl' failed */
 	}
 	else {
 		close(pfd[1]);
-		iop = fdfopen(pfd[0],0);
+		iop = fdfopen(pfd[0], O_RDONLY|O_BINARY);
 		return(iop);
 	}
 	/*NOTREACHED*/
+	return (0);	/* fake for gcc */
 }
 
 
@@ -893,7 +921,7 @@ register int *plinenum;
 {
 	char line[BUFSIZ];
 	register char *p;
-	int num_lines;
+	int num_lines = 0;
 	static int chg_num, chg_ln;
 	int lowline, highline;
 
@@ -1149,10 +1177,10 @@ struct	packet	*pkt;
 {
 	FILE	*inptr;
 	char	line[BUFSIZ];
-	int	nline, index, search_on;
+	int	nline, idx = 0, search_on = 0;
 	char	lastchar;
 
-	inptr = xfopen(file, O_RDONLY);
+	inptr = xfopen(file, O_RDONLY|O_BINARY);
 	/*
 	 * This gives the illusion that a zero-length file ends
 	 * in a newline so that it won't be mistaken for a 
@@ -1167,21 +1195,20 @@ struct	packet	*pkt;
 	      goto err;
 	   }
 	   search_on = 0;
-	   for (index=BUFSIZ-1; index >= 0; index--) {
+	   for (idx = BUFSIZ-1; idx >= 0; idx--) {
 	      if (search_on == 1) {
-		 if (line[index] == '\0') {
+		 if (line[idx] == '\0') {
 	err:
 		    fclose(inptr);
-		    inptr = NULL;
 		    sprintf(SccsError, 
 		      gettext("file '%s' contains illegal data on line %d (de14)"),
 		      file, nline);
 		    fatal(SccsError);
 		 }
 	      } else {
-		 if (line[index] == '\0') {
+		 if (line[idx] == '\0') {
 		    search_on = 1;
-		    lastchar = line[index-1];
+		    lastchar = line[idx-1];
 		    if (lastchar == '\n') {
 		       nline++;
 		    }
@@ -1191,7 +1218,6 @@ struct	packet	*pkt;
 	   (void)memset(line, '\377', BUFSIZ);
 	}
 	fclose(inptr);
-	inptr = NULL;
 	if (lastchar != '\n'){
 	   sprintf(SccsError,
 	     gettext("No newline at end of file '%s' (de18)"),
@@ -1204,8 +1230,10 @@ struct	packet	*pkt;
 /* SVR4.0 does not support getdtablesize().				  */
 /* Code should be rewritten using getrlimit() when R_NFILES is available. */
 
+#ifndef	HAVE_GETDTABLESIZE
 int
 getdtablesize()
 {
 	return (15);
 }
+#endif
