@@ -24,6 +24,15 @@
  * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)get.c	1.8 07/01/23 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)get.c 1.8 07/01/23 J. Schilling"
+#endif
 /*
  * @(#)get.c 1.59 06/12/12
  */
@@ -113,8 +122,13 @@ register char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
 	Fflags = FTLEXIT | FTLMSG | FTLCLN;
@@ -352,8 +366,7 @@ char *file;
 	}
 	strcpy(buf1, dname(Gfile));
 	strcat(buf1, template);
-	mktemp(buf1);
-	copy(buf1, Gfile);
+	Gfile[0] = '\0';		/* File not yet created */
 	first = 0;
 
 	if (gpkt.p_verbose && (num_files > 1 || had_dir || had_standinp))
@@ -442,6 +455,17 @@ char *file;
 			if (HADP) {
 				gpkt.p_gout = stdout;
 			} else {
+#ifdef	HAVE_MKSTEMP
+				close(mkstemp(buf1));	/* safer than mktemp */
+#else
+				mktemp(buf1);
+#endif
+				copy(buf1, Gfile);
+				/*
+				 * It may be better to use fdopen() and chmod()
+				 * instead of xfcreat() in order to avoind an
+				 * unlink()/create() chain.
+				 */
 				if (exists(gpkt.p_file) && (S_IEXEC & Statbuf.st_mode)) {
 					gpkt.p_gout = xfcreat(Gfile,HADK ? 
 						((mode_t)0755) : ((mode_t)0555));
@@ -501,7 +525,7 @@ char *file;
 		      }
 		   }
 		}
-		if ( exists(Gfile) ) {
+		if (Gfile[0] != '\0' && exists(Gfile) ) {
 			rename(Gfile, gfile);
 		}
 		setuid(holduid);
@@ -577,7 +601,7 @@ register struct packet *pkt;
 	if (putc((c), out) == EOF) \
 		xmsg(outname, NOGETTEXT("gen_lfile"));
 
-	in = xfopen(pkt->p_file,0);
+	in = xfopen(pkt->p_file, O_RDONLY|O_BINARY);
 	if (pkt->p_lfile) {
 		out = stdout;
 	} else {
@@ -652,13 +676,11 @@ register struct packet *pkt;
 		OUTPUTC('\n');
 	}
 	fclose(in);
-	in = NULL;
 	if (out != stdout) {
 		if (fsync(fileno(out)) < 0)
 			xmsg(outname, NOGETTEXT("gen_lfile"));
 		if (fclose(out) == EOF)
 			xmsg(outname, NOGETTEXT("gen_lfile"));
-		out = NULL;
 	}
 
 #undef	OUTPUTC
@@ -695,10 +717,14 @@ register struct packet *pkt;
 	if (n) {
 		date_ba(&pkt->p_idel[n].i_datetime,Chgdate);
 	} else {
-#ifdef XPG4		
+#ifdef XPG4
+		FILE	*xf;
+
 		if (exists(gfile))
 			unlink(gfile);
-		xfcreat(gfile, HADK ? ((mode_t)0644) : ((mode_t)0444));
+		xf = xfcreat(gfile, HADK ? ((mode_t)0644) : ((mode_t)0444));
+		if (xf)
+			fclose(xf);
 #endif
 		fatal(gettext("No sid prior to cutoff date-time (ge23)"));
 	}
@@ -719,10 +745,10 @@ static void
 makgdate(old,new)
 register char *old, *new;
 {
-	struct tm	time;
-	sscanf(old, "%d/%d/%d", &(time.tm_year), &(time.tm_mon), &(time.tm_mday));
-	time.tm_mon--;
-	strftime (new, (size_t) DATELEN, NOGETTEXT("%D"), &time);
+	struct tm	tm;
+	sscanf(old, "%d/%d/%d", &(tm.tm_year), &(tm.tm_mon), &(tm.tm_mday));
+	tm.tm_mon--;
+	strftime (new, (size_t) DATELEN, NOGETTEXT("%D"), &tm);
 }
 	
 
@@ -764,8 +790,6 @@ char line[];
 	static char str[32];
 	register char *lp, *tp;
 	int recursive = 0;
-	extern char *Type;
-	extern char *Sflags[];
 	char *expand_ID;
 		
 	cnt_ID_lines++;
@@ -941,7 +965,7 @@ register char *tp, *str, *rest;
 		}
 		tp = tline + filled_size;
 	}
-	while(*tp++ = *str++)
+	while((*tp++ = *str++) != '\0')
 		;
 	return(tp-1);
 }
@@ -1008,13 +1032,13 @@ char *inc, *exc;
 
 	if ((user=logname()) == NULL)
 	   fatal(gettext("User ID not in password file (cm9)"));
-	if ((fd=open(auxf(pkt->p_file,'q'),O_WRONLY|O_CREAT|O_EXCL,0444)) < 0) {
+	if ((fd=open(auxf(pkt->p_file,'q'),O_WRONLY|O_CREAT|O_EXCL|O_BINARY,0444)) < 0) {
 	   fatal(gettext("cannot create lock file (cm4)"));
 	}
 	fchmod(fd, (mode_t)0644);
-	out = fdfopen(fd, 1);
+	out = fdfopen(fd, O_WRONLY|O_BINARY);
 	if (exists(pfile = auxf(pkt->p_file,'p'))) {
-		in = fdfopen(xopen(pfile,(mode_t)0), (mode_t)0);
+		in = fdfopen(xopen(pfile, O_RDONLY|O_BINARY), O_RDONLY|O_BINARY);
 		while (fgets(line,sizeof(line),in) != NULL) {
 			if (fputs(line, out) == EOF)
 			   xmsg(pfile, NOGETTEXT("wrtpfile"));
@@ -1029,7 +1053,6 @@ char *inc, *exc;
 				   pf.pf_nsid.s_br == pkt->p_reqsid.s_br &&
 				   pf.pf_nsid.s_seq == pkt->p_reqsid.s_seq)) {
 					fclose(in);
-					in = NULL;
 					sprintf(SccsError,
 					   gettext("being edited: `%s' (ge17)"),
 					   line);
@@ -1042,7 +1065,6 @@ char *inc, *exc;
 			}
 		}
 		fclose(in);
-		in = NULL;
 	}
 	if (fseek(out,0L,2) == EOF)
 		xmsg(pfile, NOGETTEXT("wrtpfile"));
@@ -1068,14 +1090,14 @@ char *inc, *exc;
 		xmsg(pfile, NOGETTEXT("wrtpfile"));
 	if (fclose(out) == EOF)
 		xmsg(pfile, NOGETTEXT("wrtpfile"));
-	out = NULL;
-	if (pkt->p_verbose)
+	if (pkt->p_verbose) {
                 if (HADQ)
                    (void)fprintf(pkt->p_stdout, gettext("new version %s\n"),
 				str2);
                 else
                    (void)fprintf(pkt->p_stdout, gettext("new delta %s\n"),
 				str2);
+	}
 }
 
 /* Null routine to satisfy external reference from dodelt() */
@@ -1099,7 +1121,6 @@ fredck(pkt)
 static int
 cmrinsert ()
 {
-	extern char *Sflags[];
 	char holdcmr[CMRLIMIT];
 	char tcmr[CMRLIMIT];
 	char *p;
@@ -1132,7 +1153,7 @@ retry:
 	bad = 0;
 	isvalid = 0;
 	strcpy(tcmr, cmr);
-	while (p=strrchr(tcmr,',')) {
+	while ((p=strrchr(tcmr,',')) != NULL) {
 		++p;
 		if (cmrcheck(p,Sflags[CMFFLAG - 'a'])) {
 			++bad;
@@ -1143,7 +1164,7 @@ retry:
 		}
 		*(--p) = '\0';
 	}
-	if (*tcmr)
+	if (*tcmr) {
 		if (cmrcheck(tcmr,Sflags[CMFFLAG - 'a'])) {
 			++bad;
 		} else {
@@ -1151,6 +1172,7 @@ retry:
 			strcat(holdcmr,",");
 			strcat(holdcmr,tcmr);
 		}
+	}
 	if (!bad && holdcmr[1]) {
 	   strcpy(cmr,holdcmr+1);
 	   return(1);
