@@ -24,6 +24,15 @@
  * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)prs.c	1.5 07/01/20 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)prs.c 1.5 07/01/20 J. Schilling"
+#endif
 /*
  * @(#)prs.c 1.33 06/12/12
  */
@@ -1161,7 +1170,6 @@ register	char	*file;
 	while ((p = fgets(line,sizeof(line),iop)) != NULL)
 		printf("%s",p);
 	fclose(iop);
-	iop = NULL;
 }
 
 
@@ -1226,7 +1234,6 @@ struct packet *pkt;
 {
 	int	i;
 	int	status;
-	extern	char	Getpgm[];
 	char	str[128];
 	char	rarg[20];
 	char	filearg[80];
@@ -1309,7 +1316,6 @@ char	delchar;
 	if (!text)
 		fprintf(iop,gettext("none\n"));
 	fclose(iop);
-	iop = NULL;
 }
 
 
