@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)rmchg.c	1.6 07/01/20 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)rmchg.c 1.6 07/01/20 J. Schilling"
+#endif
 /*
  * @(#)rmchg.c 1.19 06/12/12
  */
@@ -289,13 +298,19 @@ char *file;
 	struct stat sbuf;
 	int n, numdelts;
 	char *p, *cp;
-	int keep, found;
+	int keep;
+	int found;
 	extern char Pgmr[LOGSIZE];
 	int fowner, downer, user;
 
 	if (setjmp(Fjmp))	/* set up to return here from 'fatal' */
 		return;		/* and return to caller of rmchg */
 
+	/*
+	 * Initialize here to avoid setjmp() clobbering warnings
+	 */
+	found = NO;
+
 	if (!HADR)
 		fatal(gettext("missing r (rc1)"));
 
@@ -631,7 +646,8 @@ struct packet *pkt;
 		 i=0;
 		 outhold[0]= '\0';
 		 holdptr[0]= strtok(holder,",\n");
-		 while(holdptr[++i] = strtok(0,",\n"));
+		 while((holdptr[++i] = strtok(0,",\n")) != NULL)
+			;
 		 if(!holdptr[1])
 			{
 			 /* only one mr on the list */
@@ -701,7 +717,8 @@ struct packet *pkt;
 	strcpy(holder,p);
 	mrhold[0]=strtok(holder,"\n,");
 	i=0;
-	while(mrhold[++i] = strtok(0,"\n,"));
+	while((mrhold[++i] = strtok(0,"\n,")) != NULL)
+		;
 	for(j=0;j<i;j++)
 	{
 		testcmr[j]=(char *)malloc((unsigned)strlen(mrhold[j]) + 1);
@@ -782,7 +799,6 @@ msg(app,name,cmrs,stats,sids,fred)
 		}
 	fprintf(fd,"%s chpost %s q %s sw MID=%s MFS=%s MPA=%s q q\n",app,cmrs,pname,sids,stats,logname());
 	fclose(fd);
-	fd = NULL;
 	 if(noexist) /*new termLOG make owner of /BD/source owner of file */
 	 {
 		if(stat(dir,&stbuf) == -1)
@@ -895,12 +911,10 @@ struct sid *sp;
 			sp->s_br == pf.pf_gsid.s_br &&
 			sp->s_seq == pf.pf_gsid.s_seq) {
 				fclose(in);
-				in = NULL;
 				fatal(gettext("being edited -- sid is in p-file (rc12)"));
 		}
 	}
 	fclose(in);
-	in = NULL;
 	return;
 }
 
