@@ -27,11 +27,11 @@
 /*
  * This file contains modifications Copyright 2006-2007 J. Schilling
  *
- * @(#)unget.c	1.4 07/01/11 J. Schilling
+ * @(#)unget.c	1.5 07/02/08 J. Schilling
  */
 #if defined(sun) || defined(__GNUC__)
 
-#ident "@(#)unget.c 1.4 07/01/11 J. Schilling"
+#ident "@(#)unget.c 1.5 07/02/08 J. Schilling"
 #endif
 /*
  * @(#)unget.c 1.24 06/12/12
@@ -47,6 +47,13 @@
 # include       <ctype.h>
 # include       <ccstypes.h>
 
+#ifdef	HAVE_SETRESUID
+/*
+ * HP-UX does not have seteuid(). use setresuid() instead.
+ */
+#define	seteuid(u)	setresuid((uid_t)-1, (uid_t)(u), (uid_t)-1)
+#endif
+
 /*
 		Program can be invoked as either "unget" or
 		"sact".  Sact simply displays the p-file on the
