@@ -24,6 +24,15 @@
  * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)val.c	1.5 07/01/20 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)val.c 1.5 07/01/20 J. Schilling"
+#endif
 /*
  * @(#)val.c 1.22 06/12/12
  */
@@ -846,7 +855,8 @@ register char *d_sid;
 	char *l;
 
 	while(getstats(pkt)) {
-		if (((l = get_line(pkt)) != NULL) && *l++ != CTLCHAR || *l++ != BDELTAB)
+		if ((((l = get_line(pkt)) != NULL) && *l++ != CTLCHAR) ||
+		    *l++ != BDELTAB)
 			return(1);
 		if (HADR && !(infile_err & INVALSID_ERR)) {
 			getdel(&del,l);
