@@ -27,11 +27,11 @@
 /*
  * This file contains modifications Copyright 2006-2007 J. Schilling
  *
- * @(#)defines.h	1.7 07/01/23 J. Schilling
+ * @(#)defines.h	1.8 07/02/11 J. Schilling
  */
 #if defined(sun) || defined(__GNUC__)
 
-#ident "@(#)defines.h 1.7 07/01/23 J. Schilling"
+#ident "@(#)defines.h 1.8 07/02/11 J. Schilling"
 #endif
 /*
  * @(#)defines.h 1.21 06/12/12
@@ -91,21 +91,21 @@ extern char *optarg;
 
 # define CTLSTR		"%c%c\n"
 
-# define CTLCHAR	1
-# define HEAD		'h'
+# define CTLCHAR	1	/* ^A control character sccs control prelude */
+# define HEAD		'h'	/* ^Ah sccs magic number and checksum line   */
 
-# define STATS		's'
+# define STATS		's'	/* ^A sccs stats inserted/deleted/unchanged  */
 
-# define BDELTAB	'd'
-# define INCLUDE	'i'
-# define EXCLUDE	'x'
-# define IGNORE		'g'
-# define MRNUM		'm'
-# define COMMENTS	'c'
-# define EDELTAB	'e'
+# define BDELTAB	'd'	/* ^Ad sccs delta type line		    */
+# define INCLUDE	'i'	/* ^Ai list if include serial numbers	    */
+# define EXCLUDE	'x'	/* ^Ax list of exclude serial numbers	    */
+# define IGNORE		'g'	/* ^Ag list of ignore serial numbers	    */
+# define MRNUM		'm'	/* ^Am list of mr-numbers		    */
+# define COMMENTS	'c'	/* ^Ac a sccs comment line		    */
+# define EDELTAB	'e'	/* ^Ae the end of a delta table		    */
 
-# define BUSERNAM	'u'
-# define EUSERNAM	'U'
+# define BUSERNAM	'u'	/* ^Au begin list of allowed delta users    */
+# define EUSERNAM	'U'	/* ^AU end list of allowed delta users      */
 
 # define NFLAGS	28
 
@@ -117,30 +117,30 @@ char	*Sflags[NFLAGS];	/* sync with lib/comobj/src/permiss.c */
 char	saveid[50];		/* sync with lib/comobj/src/logname.c */
 #endif
 
-# define FLAG		'f'
-# define NULLFLAG	'n'
-# define JOINTFLAG	'j'
-# define DEFTFLAG	'd'
-# define TYPEFLAG	't'
-# define VALFLAG	'v'
-# define CMFFLAG	'z'
-# define BRCHFLAG	'b'
-# define IDFLAG		'i'
-# define MODFLAG	'm'
-# define FLORFLAG	'f'
-# define CEILFLAG	'c'
-# define QSECTFLAG	'q'
-# define LOCKFLAG	'l'
-# define ENCODEFLAG	'e'
-# define SCANFLAG	's'
-# define EXPANDFLAG	'y'
+# define FLAG		'f'	/* ^Af	the begin of a flag line	    */
+# define NULLFLAG	'n'	/* ^Af n create null deltas for skipped rel */
+# define JOINTFLAG	'j'	/* ^Af j allow multiple concurrent updates  */
+# define DEFTFLAG	'd'	/* ^Af d def-SID to use for get		    */
+# define TYPEFLAG	't'	/* ^Af t mod-type used for %Y % keyword	    */
+# define VALFLAG	'v'	/* ^Af v val-prog used or mr-flags	    */
+# define CMFFLAG	'z'	/* ^Af z CMFFLAG ????			    */
+# define BRCHFLAG	'b'	/* ^Af b enables branch deltas		    */
+# define IDFLAG		'i'	/* ^Af i "No id keywords (ge6)" is an error */
+# define MODFLAG	'm'	/* ^Af m mod-name used for %M % keyword	    */
+# define FLORFLAG	'f'	/* ^Af f floor-rel allowed to check out	    */
+# define CEILFLAG	'c'	/* ^Af c ceiling-rel allowed to check out   */
+# define QSECTFLAG	'q'	/* ^Af m mod-name used for %Q % keyword	    */
+# define LOCKFLAG	'l'	/* ^Af l ll relase list locked for get -e   */
+# define ENCODEFLAG	'e'	/* ^Af e The content is UUencoded	    */
+# define SCANFLAG	's'	/* ^Af s # of lines to be scanned f. keyw.  */
+# define EXPANDFLAG	'y'	/* ^Af y list of sccs keywords to be exp.   */
 
-# define BUSERTXT	't'
-# define EUSERTXT	'T'
+# define BUSERTXT	't'	/* ^At sccs file specific comment start	    */
+# define EUSERTXT	'T'	/* ^AT sccs file specific comment end	    */
 
-# define INS		'I'
-# define DEL		'D'
-# define END		'E'
+# define INS		'I'	/* ^AI release Insert block start	    */
+# define DEL		'D'	/* ^AD release Delete block start	    */
+# define END		'E'	/* ^AE release Insert/Delete block end	    */
 
 # define MINR		1		/* minimum release number */
 # define MAXR		9999		/* maximum release number */
