@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)filehand.c	1.4 07/01/09 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)filehand.c 1.4 07/01/09 J. Schilling"
+#endif
 /*
  * @(#)filehand.c 1.4 06/12/12
  */
