@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)fmalloc.c	1.3 07/01/11 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)fmalloc.c 1.3 07/01/11 J. Schilling"
+#endif
 /*
  * @(#)fmalloc.c 1.5 06/12/12
  */
@@ -48,7 +57,6 @@
 #include <defines.h>
 
 #define LCHUNK	100
-/*#define NULL	0*/
 
 static unsigned	ptrcnt = 0;
 static unsigned	listsize = 0;
