@@ -24,6 +24,15 @@
  * Copyright 1994 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)trnslat.c	1.4 07/01/20 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)trnslat.c 1.4 07/01/20 J. Schilling"
+#endif
 /*
  * @(#)trnslat.c 1.3 06/12/12
  */
@@ -43,7 +52,7 @@ char *old, *new, *result;
 {
 	register char *r, *o;
 
-	for (r = result; *r = *str++; r++)
+	for (r = result; (*r = *str++) != '\0'; r++)
 		for (o = old; *o; )
 			if (*r == *o++) {
 				*r = new[o - old -1];
