@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)userexit.c	1.3 07/01/11 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)userexit.c 1.3 07/01/11 J. Schilling"
+#endif
 /*
  * @(#)userexit.c 1.4 06/12/12
  */
